@@ -1,3 +1,6 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
 #include "xfce-mixer-info.h"
@@ -6,20 +9,20 @@
 
 static GtkItemFactoryEntry menubar_items[] =
 {
-{"/_File", NULL, NULL, 0, "<Branch>"},
-{"/File/_Options", "<control>o", options_activate_cb, 0, "<Item>"},
-{"/File/_Exit", "<control>x", appexit_activate_cb, 0, "<Item>"},
-{"/_View", NULL, NULL, 0, "<Branch>"},
-{"/View/sep", NULL, NULL, 0, "<Separator>"},
-{"/View/_Manage", "<control>p", profile_mgr_activate_cb, 0, "<Item>"},
-{"/_Help", NULL, NULL, 0, "<Branch>"},
-{"/Help/_Info", NULL, info_activate_cb, 0, "<Item>"}
+{N_("/_File"), NULL, NULL, 0, "<Branch>"},
+{N_("/File/_Options"), "<control>o", options_activate_cb, 0, "<Item>"},
+{N_("/File/_Exit"), "<control>x", appexit_activate_cb, 0, "<Item>"},
+{N_("/_View"), NULL, NULL, 0, "<Branch>"},
+{N_("/View/sep"), NULL, NULL, 0, "<Separator>"},
+{N_("/View/_Manage"), "<control>p", profile_mgr_activate_cb, 0, "<Item>"},
+{N_("/_Help"), NULL, NULL, 0, "<Branch>"},
+{N_("/Help/_Info"), NULL, info_activate_cb, 0, "<Item>"}
 };
 
 static const char *
 translate_menu (const char *msg, gpointer data)
 {
-	return dgettext (GETTEXT_PACKAGE, msg);
+	return _(msg); /*dgettext (GETTEXT_PACKAGE, msg);*/
 } 
 
 GtkMenuBar *
